==> environment_switch-0.0.3.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:environment_switch/environment_switch.dart';

void main() {



  
  runApp(MyApp());

 
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();


}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';

  @override
  void initState() {
    super.initState();
    initPlatformState();
    initsdk();
  }

   void initsdk() async {
    WidgetsFlutterBinding.ensureInitialized();
    await EnvironmentSwitch.getInstance();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      platformVersion = await EnvironmentSwitch.platformVersion;
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: MYTest(),
        ),
      ),
    );
  }
}

class MYTest extends StatelessWidget {
  @override
  Widget build(Object context) {
    return GestureDetector(
      child: Text("1111111111"),
      onTap: () {
        EnvironmentSwitch.show(context);
      },
    );
  }
}

==> environment_switch-0.0.6.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:environment_switch/environment_switch.dart';

void main() {
 

  runApp(MyApp());
}


class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  @override
  void initState() {
    super.initState();
    initPlatformState();
    initsdk();
  }

  void initsdk() async {
    WidgetsFlutterBinding.ensureInitialized();
    await EnvironmentSwitch.getInstance();

       print(EnvironmentSwitch.getEnv());

  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    var platformVersion;

   
   

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: MYTest(),
        ),
      ),
    );
  }
}

class MYTest extends StatelessWidget {
  @override
  Widget build(Object context) {
    return GestureDetector(
      child: Text("1111111111"),
      onTap: () {
        EnvironmentSwitch.show(context);
      },
    );
  }
}
